==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/infrastructure/packet/s2c/ElevatorFloorListPacket.java <==
package com.zurrtum.create.infrastructure.packet.s2c;

import com.zurrtum.create.AllClientHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import com.zurrtum.create.catnip.data.Couple;
import com.zurrtum.create.catnip.data.IntAttached;
import com.zurrtum.create.content.contraptions.AbstractContraptionEntity;
import java.util.List;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record ElevatorFloorListPacket(int entityId, List<IntAttached<Couple<String>>> floors) implements class_2596<class_2602> {
    public static final class_9139<class_9129, ElevatorFloorListPacket> CODEC = class_9139.method_56435(
        class_9135.field_49675,
        ElevatorFloorListPacket::entityId,
        CatnipStreamCodecBuilders.list(IntAttached.streamCodec(Couple.streamCodec(class_9135.field_48554))),
        ElevatorFloorListPacket::floors,
        ElevatorFloorListPacket::new
    );

    public ElevatorFloorListPacket(AbstractContraptionEntity entity, List<IntAttached<Couple<String>>> floors) {
        this(entity.method_5628(), floors);
    }

    @Override
    public void apply(class_2602 listener) {
        AllClientHandle.INSTANCE.onElevatorFloorList(listener, this);
    }

    @Override
    public class_9145<ElevatorFloorListPacket> method_65080() {
        return AllPackets.UPDATE_ELEVATOR_FLOORS;
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/infrastructure/packet/s2c/ElevatorFloorListPacket.java <==
package com.zurrtum.create.infrastructure.packet.s2c;

import com.zurrtum.create.AllClientHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import com.zurrtum.create.catnip.data.Couple;
import com.zurrtum.create.catnip.data.IntAttached;
import com.zurrtum.create.content.contraptions.AbstractContraptionEntity;
import java.util.List;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record ElevatorFloorListPacket(int entityId, List<IntAttached<Couple<String>>> floors) implements class_2596<class_2602> {
    public static final class_9139<class_9129, ElevatorFloorListPacket> CODEC = class_9139.method_56435(
        class_9135.field_49675,
        ElevatorFloorListPacket::entityId,
        CatnipStreamCodecBuilders.list(IntAttached.streamCodec(Couple.streamCodec(class_9135.field_48554))),
        ElevatorFloorListPacket::floors,
        ElevatorFloorListPacket::new
    );

    public ElevatorFloorListPacket(AbstractContraptionEntity entity, List<IntAttached<Couple<String>>> floors) {
        this(entity.method_5628(), floors);
    }

    @Override
    public void handle(class_2602 listener) {
        AllClientHandle.INSTANCE.onElevatorFloorList(listener, this);
    }

    @Override
    public class_9145<ElevatorFloorListPacket> method_65080() {
        return AllPackets.UPDATE_ELEVATOR_FLOORS;
    }
}
